@@ -5,7 +5,10 @@ use base qw/ Class::Accessor /;
 __PACKAGE__->follow_best_practice;
 __PACKAGE__->mk_accessors(qw/ public_key private_key /);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
+
+sub get_endpoint    { "http://gateway.marvel.com" }
+sub get_api_version { "v1" }
 
 =head1 NAME
 
